@@ -198,11 +198,6 @@ pub fn get_config() -> (Config, usize) {
             Arg::with_name("disable-cachebuster")
                 .long("disable-cachebuster")
         )
-        /*.arg(
-            Arg::with_name("verify")
-                .long("verify")
-                .help("verify found params")
-        )*/
         .arg(
             Arg::with_name("value_size")
                 .long("value-size")
@@ -231,7 +226,7 @@ pub fn get_config() -> (Config, usize) {
         .arg(
             Arg::with_name("http2")
                 .long("http2")
-                .help("Use http/2 instead of http/1.1")
+                .help("Prefer http/2 over http/1.1")
         );
 
     let args = app.clone().get_matches();
@@ -366,15 +361,10 @@ pub fn get_config() -> (Config, usize) {
         headers.insert(String::from("User-Agent"), String::from("Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.97 Safari/537.36"));
     }
 
-    //let origin_cachebuster_value: String = "Origin:https://{{random}}.{{host}}".replace("{{host}}", host);
-
     if !args.is_present("disable-cachebuster") {
         if !headers.keys().any(|i| i.contains("Accept")) {
             headers.insert(String::from("Accept"), String::from("*/*, text/{{random}}"));
         }
-        /*if !headers.keys().any(|i| i.contains("Origin")) {
-            headers.push(&origin_cachebuster_value);
-        }*/
         if !headers.keys().any(|i| i.contains("Accept-Language")) {
             headers.insert(
                 String::from("Accept-Language"),
@@ -426,11 +416,13 @@ pub fn get_config() -> (Config, usize) {
     }
 
     if parameter_template.is_empty() {
-        if body_type.contains("urlencode") {
-            parameter_template = "%k=%v&";
-        } else if body_type.contains("json") {
+        if body_type.contains("json") && args.is_present("as_body") {
             parameter_template = "\"%k\":\"%v\", ";
-        }
+        } else if body_type.contains("urlencode") {
+            parameter_template = "%k=%v&";
+        } /*else {
+            parameter_template = "%k=%v&";
+        }*/
     }
 
 
@@ -508,7 +500,6 @@ pub fn get_config() -> (Config, usize) {
         test: args.is_present("test"),
         verbose,
         disable_cachebuster: args.is_present("disable-cachebuster"),
-        //verify: args.is_present("verify"),
         delay,
         value_size,
         learn_requests_count,
