@@ -50,10 +50,17 @@ pub fn compare(
         code = false
     }
 
-    for diff in check_diffs(
+    //just push every found diff to the vector of diffs
+    for diff in match diff(
         &initial_response.text,
         &response.text,
     ) {
+        Ok(val) => val,
+        Err(err) => {
+            writeln!(io::stderr(), "Unable to compare: {}", err).ok();
+            std::process::exit(1);
+        }
+    } {
         if !diffs.contains(&diff) {
             diffs.push(diff);
         } else {
@@ -269,20 +276,6 @@ pub fn make_hashmap(
     hashmap
 }
 
-//use internal diff to compare responses
-pub fn check_diffs(
-    resp1: &str,
-    resp2: &str
-) -> Vec<String> {
-    match diff(resp1, resp2) {
-        Ok(val) => val,
-        Err(err) => {
-            writeln!(io::stderr(), "Unable to compare: {}", err).ok();
-            std::process::exit(1);
-        }
-    }
-}
-
 pub fn parse_request(insecure: bool, request: &str, config: Config) -> Option<Config> {
     let mut lines = request.lines();
     let mut host = String::new();
@@ -291,7 +284,7 @@ pub fn parse_request(insecure: bool, request: &str, config: Config) -> Option<Co
     let proto = if insecure { "http://" } else { "https://" };
     let mut firstline = lines.next()?.split(' ');
     let method = firstline.next()?.to_string();
-    let path = firstline.next()?.to_string();
+    let mut path = firstline.next()?.to_string();
 
     let http2: bool = firstline.next()?.to_string().contains("HTTP/2");
 
@@ -315,7 +308,12 @@ pub fn parse_request(insecure: bool, request: &str, config: Config) -> Option<Co
 
         match key.to_lowercase().as_str() {
             "content-type" => content_type = value.clone(),
-            "host" => host = value.clone(),
+            "host" => {
+                host = value.clone();
+                if http2 {
+                    continue
+                }
+            },
             "content-length" => continue,
             _ => ()
         };
@@ -323,7 +321,12 @@ pub fn parse_request(insecure: bool, request: &str, config: Config) -> Option<Co
         headers.insert(key.to_string(), value);
     }
 
-    let body = lines.next().unwrap_or("");
+    let mut body = lines.next().unwrap_or("").to_string();
+    while let Some(part) = lines.next() {
+        if !part.is_empty() {
+            body.push_str(part);
+        }
+    }
 
     //check whether the body type can be json
     let body_type = if config.body_type.contains('-') && config.as_body
@@ -336,16 +339,19 @@ pub fn parse_request(insecure: bool, request: &str, config: Config) -> Option<Co
 
     //if --as-body is specified and body is empty or lacks injection points - add an injection point
     let body = if config.as_body && ((!body.is_empty() && !body.contains("%s")) || body.is_empty()) {
-        adjust_body(body, &body_type)
+        adjust_body(&body, &body_type)
     } else {
-        body.to_string()
+        body
     };
 
     let mut url = [proto.to_string(), host.clone(), path.clone()].concat();
+    let initial_url = url.clone();
     if !config.as_body && url.contains('?') && url.contains('=') && !url.contains("%s") {
         url.push_str("&%s");
+        path.push_str("&%s");
     } else if !config.as_body {
         url.push_str("?%s");
+        path.push_str("?%s");
     }
 
     Some(Config {
@@ -358,6 +364,7 @@ pub fn parse_request(insecure: bool, request: &str, config: Config) -> Option<Co
         body_type,
         parameter_template,
         http2,
+        initial_url,
         ..config
     })
 }
